==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerinstance/kotlin/inputs/SecurityContextCapabilitiesDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerinstance.kotlin.inputs

import com.pulumi.azurenative.containerinstance.inputs.SecurityContextCapabilitiesDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The capabilities to add or drop from a container.
 * @property add The capabilities to add to the container.
 * @property drop The capabilities to drop from the container.
 */
public data class SecurityContextCapabilitiesDefinitionArgs(
    public val add: Output<List<String>>? = null,
    public val drop: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerinstance.inputs.SecurityContextCapabilitiesDefinitionArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerinstance.inputs.SecurityContextCapabilitiesDefinitionArgs =
        com.pulumi.azurenative.containerinstance.inputs.SecurityContextCapabilitiesDefinitionArgs.builder()
            .add(add?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .drop(drop?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [SecurityContextCapabilitiesDefinitionArgs].
 */
@PulumiTagMarker
public class SecurityContextCapabilitiesDefinitionArgsBuilder internal constructor() {
    private var add: Output<List<String>>? = null

    private var drop: Output<List<String>>? = null

    /**
     * @param value The capabilities to add to the container.
     */
    @JvmName("kubdxurxbvnuufel")
    public suspend fun add(`value`: Output<List<String>>) {
        this.add = value
    }

    @JvmName("qreoplfjvccjlynb")
    public suspend fun add(vararg values: Output<String>) {
        this.add = Output.all(values.asList())
    }

    /**
     * @param values The capabilities to add to the container.
     */
    @JvmName("uvwvwvlhnlyviuec")
    public suspend fun add(values: List<Output<String>>) {
        this.add = Output.all(values)
    }

    /**
     * @param value The capabilities to drop from the container.
     */
    @JvmName("yvrsfjvjwjclujfi")
    public suspend fun drop(`value`: Output<List<String>>) {
        this.drop = value
    }

    @JvmName("qqlnesybmfodvpfw")
    public suspend fun drop(vararg values: Output<String>) {
        this.drop = Output.all(values.asList())
    }

    /**
     * @param values The capabilities to drop from the container.
     */
    @JvmName("odboeukkcacpjkok")
    public suspend fun drop(values: List<Output<String>>) {
        this.drop = Output.all(values)
    }

    /**
     * @param value The capabilities to add to the container.
     */
    @JvmName("oynprnsstwfiqebb")
    public suspend fun add(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.add = mapped
    }

    /**
     * @param values The capabilities to add to the container.
     */
    @JvmName("obreqpwkeppvevcc")
    public suspend fun add(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.add = mapped
    }

    /**
     * @param value The capabilities to drop from the container.
     */
    @JvmName("qhwylhrnkgqkwcgt")
    public suspend fun drop(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.drop = mapped
    }

    /**
     * @param values The capabilities to drop from the container.
     */
    @JvmName("ixgjygvqjgeqkdra")
    public suspend fun drop(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.drop = mapped
    }

    internal fun build(): SecurityContextCapabilitiesDefinitionArgs =
        SecurityContextCapabilitiesDefinitionArgs(
            add = add,
            drop = drop,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerinstance/kotlin/inputs/SecurityContextCapabilitiesDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerinstance.kotlin.inputs

import com.pulumi.azurenative.containerinstance.inputs.SecurityContextCapabilitiesDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The capabilities to add or drop from a container.
 * @property add The capabilities to add to the container.
 * @property drop The capabilities to drop from the container.
 */
public data class SecurityContextCapabilitiesDefinitionArgs(
    public val add: Output<List<String>>? = null,
    public val drop: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerinstance.inputs.SecurityContextCapabilitiesDefinitionArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerinstance.inputs.SecurityContextCapabilitiesDefinitionArgs =
        com.pulumi.azurenative.containerinstance.inputs.SecurityContextCapabilitiesDefinitionArgs.builder()
            .add(add?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .drop(drop?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [SecurityContextCapabilitiesDefinitionArgs].
 */
@PulumiTagMarker
public class SecurityContextCapabilitiesDefinitionArgsBuilder internal constructor() {
    private var add: Output<List<String>>? = null

    private var drop: Output<List<String>>? = null

    /**
     * @param value The capabilities to add to the container.
     */
    @JvmName("iceppebkdavaypbn")
    public suspend fun add(`value`: Output<List<String>>) {
        this.add = value
    }

    @JvmName("uxqkuwhocymueqwa")
    public suspend fun add(vararg values: Output<String>) {
        this.add = Output.all(values.asList())
    }

    /**
     * @param values The capabilities to add to the container.
     */
    @JvmName("macgkqjodjweyeud")
    public suspend fun add(values: List<Output<String>>) {
        this.add = Output.all(values)
    }

    /**
     * @param value The capabilities to drop from the container.
     */
    @JvmName("oqisnjxndnqytsnb")
    public suspend fun drop(`value`: Output<List<String>>) {
        this.drop = value
    }

    @JvmName("csuryvebansngmut")
    public suspend fun drop(vararg values: Output<String>) {
        this.drop = Output.all(values.asList())
    }

    /**
     * @param values The capabilities to drop from the container.
     */
    @JvmName("bkomnbgmqalrtmnn")
    public suspend fun drop(values: List<Output<String>>) {
        this.drop = Output.all(values)
    }

    /**
     * @param value The capabilities to add to the container.
     */
    @JvmName("vbroehigunwcryrv")
    public suspend fun add(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.add = mapped
    }

    /**
     * @param values The capabilities to add to the container.
     */
    @JvmName("xnmpiesnmeipndaq")
    public suspend fun add(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.add = mapped
    }

    /**
     * @param value The capabilities to drop from the container.
     */
    @JvmName("pafpuopvuayqwsqq")
    public suspend fun drop(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.drop = mapped
    }

    /**
     * @param values The capabilities to drop from the container.
     */
    @JvmName("nsrhefdnfgrxhcml")
    public suspend fun drop(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.drop = mapped
    }

    internal fun build(): SecurityContextCapabilitiesDefinitionArgs =
        SecurityContextCapabilitiesDefinitionArgs(
            add = add,
            drop = drop,
        )
}
